aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoas Schilling <nickvergessen@gmx.de>2013-04-30 10:37:59 +0200
committerJoas Schilling <nickvergessen@gmx.de>2013-04-30 10:37:59 +0200
commit4810c61fd7b912ea2914b99f7db502b6f503068f (patch)
tree4075eecee54c7b637b9977ad3c6aad876381b878
parent8a4260703fa76bb92f144b527b3d55289568db74 (diff)
downloadforums-4810c61fd7b912ea2914b99f7db502b6f503068f.tar
forums-4810c61fd7b912ea2914b99f7db502b6f503068f.tar.gz
forums-4810c61fd7b912ea2914b99f7db502b6f503068f.tar.bz2
forums-4810c61fd7b912ea2914b99f7db502b6f503068f.tar.xz
forums-4810c61fd7b912ea2914b99f7db502b6f503068f.zip
[ticket/11495] Remove get_parent_data from interface and rename it
The method is implementation specific and has no use, apart from cache, that is not covered by get_path_data(). PHPBB3-11495
-rw-r--r--phpBB/includes/tree/interface.php9
-rw-r--r--phpBB/includes/tree/nestedset.php9
-rw-r--r--tests/tree/nestedset_forum_get_data_test.php8
3 files changed, 10 insertions, 16 deletions
diff --git a/phpBB/includes/tree/interface.php b/phpBB/includes/tree/interface.php
index 1b462768a0..bd8181beb2 100644
--- a/phpBB/includes/tree/interface.php
+++ b/phpBB/includes/tree/interface.php
@@ -119,13 +119,4 @@ interface phpbb_tree_interface
* ID => Item data
*/
public function get_subtree_data($item_id, $order_desc, $include_item);
-
- /**
- * Get base information of parent items
- *
- * @param array $item The item to get the branch from
- * @return array Array of items (containing basic columns from the item table)
- * ID => Item data
- */
- public function get_parent_data(array $item);
}
diff --git a/tests/tree/nestedset_forum_get_data_test.php b/tests/tree/nestedset_forum_get_data_test.php
index 300bbc6bfa..7a4fada880 100644
--- a/tests/tree/nestedset_forum_get_data_test.php
+++ b/tests/tree/nestedset_forum_get_data_test.php
@@ -95,7 +95,7 @@ class phpbb_tests_tree_nestedset_forum_get_data_test extends phpbb_tests_tree_ne
$this->assertEquals($expected, array_keys($this->set->get_subtree_data($forum_id, $order_desc, $include_item)));
}
- public function get_parent_data_data()
+ public function get_path_basic_data_data()
{
return array(
array(1, array(), array()),
@@ -108,10 +108,10 @@ class phpbb_tests_tree_nestedset_forum_get_data_test extends phpbb_tests_tree_ne
}
/**
- * @dataProvider get_parent_data_data
+ * @dataProvider get_path_basic_data_data
*/
- public function test_get_parent_data($forum_id, $forum_data, $expected)
+ public function test_get_path_basic_data($forum_id, $forum_data, $expected)
{
- $this->assertEquals($expected, array_keys($this->set->get_parent_data(array_merge($this->forum_data[$forum_id], $forum_data))));
+ $this->assertEquals($expected, array_keys($this->set->get_path_basic_data(array_merge($this->forum_data[$forum_id], $forum_data))));
}
}
diff --git a/phpBB/includes/tree/nestedset.php b/phpBB/includes/tree/nestedset.php
index 10ab6a86e3..89a91ccb16 100644
--- a/phpBB/includes/tree/nestedset.php
+++ b/phpBB/includes/tree/nestedset.php
@@ -595,13 +595,16 @@ abstract class phpbb_tree_nestedset implements phpbb_tree_interface
}
/**
* Get base information of parent items
*
+ * Basic data is defined in the $item_basic_data property.
* Data is cached in the item_parents column in the item table
*
- * @inheritdoc
+ * @param array $item The item to get the path from
+ * @return array Array of items (containing basic columns from the item table)
+ * ID => Item data
*/
- public function get_parent_data(array $item)
+ public function get_path_basic_data(array $item)
{
$parents = array();
if ((int) $item[$this->column_parent_id])
@@ -595,13 +595,16 @@ abstract class phpbb_tree_nestedset implements phpbb_tree_interface
}
/**
- * Get base information of parent items
+ * Get basic data of all parent items
*